@@ -18,11 +18,11 @@ sample_assets = \
 }
 
 sample_flattened = [
-    {"name": "A", "value": 9.9, "name_0": "A"},
-    {"name": "A_A", "value": 2.2, "name_0": "A", "name_1": "A_A"},
-    {"name": "A_A_A", "value": 23, "name_0": "A", "name_1": "A_A", "name_2": "A_A_A"},
-    {"name": "A_A_B", "value": 32, "name_0": "A", "name_1": "A_A", "name_2": "A_A_B"},
-    {"name": "A_B", "value": 100, "name_0": "A", "name_1": "A_B"},
+    {"name": "A", "value": 9.9, "name_0": "A", "accountId": None},
+    {"name": "A_A", "value": 2.2, "name_0": "A", "name_1": "A_A", "accountId": None},
+    {"name": "A_A_A", "value": 23, "name_0": "A", "name_1": "A_A", "name_2": "A_A_A", "accountId": None},
+    {"name": "A_A_B", "value": 32, "name_0": "A", "name_1": "A_A", "name_2": "A_A_B", "accountId": None},
+    {"name": "A_B", "value": 100, "name_0": "A", "name_1": "A_B", "accountId": None},
 ]
 
 def test_flatten():
